@@ -72,9 +72,9 @@ define('io.ox/tours/intro', [
             .title(gt('Creating new items'))
             .content(gt('To create a new E-Mail, click the Compose new E-Mail in the toolbar.'))
             .navigateTo('io.ox/mail/main')
-            .waitFor('.io-ox-mail-window .primary-action .btn:visible, .classic-toolbar .io-ox-action-link:visible:first')
-            .hotspot('.io-ox-mail-window .primary-action .btn:visible, .classic-toolbar .io-ox-action-link:visible:first')
-            .referTo('.io-ox-mail-window .primary-action .btn:visible, .classic-toolbar .io-ox-action-link:visible:first')
+            .waitFor('.io-ox-mail-window .primary-action .btn:visible, .classic-toolbar [data-action="io.ox/mail/actions/compose"]:visible')
+            .hotspot('.io-ox-mail-window .primary-action .btn:visible, .classic-toolbar [data-action="io.ox/mail/actions/compose"]:visible')
+            .referTo('.io-ox-mail-window .primary-action .btn:visible, .classic-toolbar [data-action="io.ox/mail/actions/compose"]:visible')
             .end()
         .step()
             .title(gt('Opening or closing the folder tree'))
